-- -- COPYRIGHT NOTICE -- --
-- This work is covered by the LGPL License. You are
-- able to modify, distribute and sublicense this
-- work as long as you include the original or show
-- clearly how to obtain it.

-- NOTES:
-- - Filename:   ParseChat.lua
-- - Written By: Trilesch and Digpoe
-- - Purpose:    Parses chat logs for useful data.

ParseChat = {}

-- ParserType Enum
ParseChat.ParserType = {
	PARSE_HIT_TYPE    = 1,
	PARSE_DAMAGE_DONE = 2,
	PARSE_DAMAGE_TYPE = 3,
	PARSE_DAMAGE_MODF = 4,
	PARSE_HEAL_SPELL  = 5,
	PARSE_HEAL_POINTS = 6,
	PARSE_HEAL_CASTER = 7
}

-- Valid formats to use
local Formats = {
	"<rgb=#%x+>([^<]+)</rgb>",         -- Returns hit type. Example match: '<rgb=#FFFFFF>critical hit</rgb>' or '<rgb=#0A0A0A>hit</rgb>'
	"for (%d+%.?%d*) ",                -- Returns a string representation of a digit. Example match: 'for 10 asdasdasd' or 'for 999.999 damage'
	"%d+%.?%d* ([%w ]+) to [%w ]+%.$", -- Returns damage type. Example match: '10 Common damage to Morale.' or '195.9845 Magic damage to Morale'
	" to ([%w ]+)%.$",                 -- Returns damage modifier. Example match: 'Morale.' or 'Awesome.'
	"^([%w ]+) applied",               -- Returns heal spell. Example match: 'Prelude to Hope applied' or 'Hello World applied'
	"restoring (%d+) point",           -- Returns heal points. Example match: 'restoring 1 point' or 'restoring 5 points'
	"^[^ ]+"                           -- Returns healer. Example match: 'Digpoe' or 'Trilesch asdasd'
}

-- ParseMessage function: Expects the message and the format (a ParserType) to parse it in.
-- ParseMessage function: Returns the first message which matches the format.
function ParseChat.ParseMessage(message, format)
	assert(type(message) == "string", "Supplied message is not a string.")
	assert((type(format) == "number") and (Formats[format]), "Supplied format is not a valid format.")

	return message:match(Formats[format])
end